@@ -97,7 +97,17 @@ void ConfigDialog::onAddTriggered()
 
         if (agentType.isValid()) {
             auto job = new Akonadi::AgentInstanceCreateJob(agentType, this);
-            job->configure(this);
+            connect(job, &Akonadi::AgentInstanceCreateJob::result, this, [this, job](KJob *) {
+                if (job->error()) {
+                    return;
+                }
+                auto configureDialog = new Akonadi::AgentConfigurationDialog(job->instance(), this);
+                configureDialog->setAttribute(Qt::WA_DeleteOnClose);
+                connect(configureDialog, &QDialog::rejected, this, [instance = job->instance()] {
+                    Akonadi::AgentManager::self()->removeInstance(instance);
+                });
+                configureDialog->show();
+            });
             job->start();
         }
     }
