@@ -1,26 +1,9 @@
-/* This file is part of Zanshin
+/*
+ * SPDX-FileCopyrightText: 2014 Franck Arrecot <franck.arrecot@gmail.com>
+   SPDX-FileCopyrightText: 2014 Rémi Benoit <r3m1.benoit@gmail.com>
+   * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+   */
 
-   Copyright 2014 Franck Arrecot <franck.arrecot@gmail.com>
-   Copyright 2014 Rémi Benoit <r3m1.benoit@gmail.com>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
-*/
 
 #ifndef AKONADI_CONTEXTQUERIES_H
 #define AKONADI_CONTEXTQUERIES_H
@@ -33,8 +16,9 @@
 
 namespace Akonadi {
 
-class ContextQueries : public Domain::ContextQueries
+class ContextQueries : public QObject, public Domain::ContextQueries
 {
+    Q_OBJECT
 public:
     typedef QSharedPointer<ContextQueries> Ptr;
 
